/* 
 * File:   main.c
 * Author: GrosSylvestre
 *
 * Created on February 26, 2023, 2:31 PM
 */

#include <stdio.h>
#include <stdlib.h>

// CONFIG1
//#pragma config FOSC = INTRC_NOCLKOUT// Oscillator Selection bits (INTOSCIO oscillator: I/O function on RA6/OSC2/CLKOUT pin, I/O function on RA7/OSC1/CLKIN)
#pragma config FOSC = XT        // Oscillator Selection bits (XT oscillator: Crystal/resonator on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN)
#pragma config WDTE = OFF        // Watchdog Timer Enable bit (WDT enabled)
#pragma config PWRTE = OFF      // Power-up Timer Enable bit (PWRT disabled)
#pragma config MCLRE = OFF      // RE3/MCLR pin function select bit (RE3/MCLR pin function is digital input, MCLR internally tied to VDD)
#pragma config CP = OFF         // Code Protection bit (Program memory code protection is disabled)
#pragma config CPD = OFF        // Data Code Protection bit (Data memory code protection is disabled)
#pragma config BOREN = ON       // Brown Out Reset Selection bits (BOR enabled)
#pragma config IESO = ON        // Internal External Switchover bit (Internal/External Switchover mode is enabled)
#pragma config FCMEN = ON       // Fail-Safe Clock Monitor Enabled bit (Fail-Safe Clock Monitor is enabled)
#pragma config LVP = OFF        // Low Voltage Programming Enable bit (RB3 pin has digital I/O, HV on MCLR must be used for programming)

// CONFIG2
#pragma config BOR4V = BOR40V   // Brown-out Reset Selection bit (Brown-out Reset set to 4.0V)
#pragma config WRT = OFF        // Flash Program Memory Self Write Enable bits (Write protection off)

// #pragma config statements should precede project file includes.
// Use project enums instead of #define for ON and OFF.

#include <xc.h>
#include "pic16f887.h"
#define _XTAL_FREQ (8000000)


/*
 * 
 */
void ADC_Init(void)
{
    ADCON0=0b01000000;  // sampling freq=osc_freq/8,ADC off initially
    ADCON1=0x00;  // All pins are configured as Analog pins and ADC result is left justified  
	ANSEL = 0x01;	//turn off all other analog inputs
	ANSELH = 0x00;
 	ANSELbits.ANS0 = 1;	// turn on RA0 analog   
}

unsigned char ADC_Convert()
{ // start an ADC conversion and return the 8 most-significant bits of the result
    ADCON0bits.GO_DONE = 1;             // start conversion
    while (ADCON0bits.GO_DONE == 1);    // wait for it to complete
    return ADRESH;                      // return high byte of result
}

void tempo(unsigned char z)
{
    while (z >0)
    {
        __delay_ms(1);
        z--;
    }
}

void  main(void) {

    // oscillateur interne  8 MHz
    OSCCON = 0b01110111;
    
    // init IO
    TRISD = 0x00; 	// PORTD to output (0) 

    // RA0 en entre potentiomtre
    TRISA = 0xff;		// TRISA0 input
    
    const unsigned char LED_LookupTable[8] = {0x01, 0x02, 0x04, 0x08,
												 0x10, 0x20, 0x40, 0x80};

    unsigned char x = 0; // pour les leds qui tournent
    unsigned char y; // pour la vitesse de rotation
    
    // Init ADC
    ADC_Init();
    ADCON0bits.ADON = 1;
    
    while(1)
    {
        PORTD = LED_LookupTable[x];  
        ADCON0bits.ADON = 1;

        y = ADC_Convert();
        tempo(y);
        
        x += 1;        
        if(x > 7)
            x = 0;
        
    }    
}




